use crate::prelude::*;

/// Validates a new account
#[inline]
async fn check_new_account_name(
    bot: &Throttle<Bot>,
    msg: &Message,
    db: &DatabaseConnection,
    name: &str,
) -> crate::Result<Option<Message>> {
    let user_id = msg.from().ok_or(NoUserInfo)?.id.0;
    if Account::exists(user_id, name, db).await? {
        let msg = bot
            .send_message(msg.chat.id, "Account already exists")
            .await?;
        return Ok(Some(msg));
    }
    if !validate_field(name) {
        let msg = bot
            .send_message(msg.chat.id, "Invalid account name. Try again")
            .await?;
        return Ok(Some(msg));
    }

    Ok(None)
}

crate::simple_state_handler!(
    get_new_name,
    check_new_account_name,
    "Couldn't get the text of the message. Send the name of the new account again"
);
